ParseError enum

Why a dewbead record could not be parsed.

Inheritance
Available extensions

Values

empty → const ParseError
notADewbead → const ParseError
missingTitleMarker → const ParseError
malformedDatetime → const ParseError
malformedEndpoint → const ParseError
invalidClock → const ParseError
invalidDate → const ParseError
multipleEndpoints → const ParseError
todoWithEndpoint → const ParseError

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ParseError>
A constant List of the values in this enum, in order of their declaration.