ParsedEvent class

A fully resolved calendar item.

start/end are naive local DateTimes (wall-clock in NOW's zone; never UTC, so toIso8601String() never emits Z). For DewbeadType.todo the deadline is in end and start is null.

Constructors

ParsedEvent({required DewbeadType type, String? title, bool isAllDay = false, DateTime? start, DateTime? end, String? location, Set<ReviewFlag> review = const {}})
const

Properties

end DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
isAllDay bool
final
location String?
final
review Set<ReviewFlag>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime?
final
title String?
final
type DewbeadType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override