RelativeTime class final

n ±N… — added to NOW. The parser guarantees the owning date_part is TodayDate(0) when the time is a RelativeTime; the AST does not re-check.

Inheritance

Constructors

RelativeTime(List<Delta> deltas)
const

Properties

deltas List<Delta>
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override